@@ -14,7 +14,8 @@ reboot=`zenity --question --title CleaN900 --text "Are you sure you want to rest
 
 if [ "$reboot" -eq 0 ]
 	then
-		dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Restarting... Please wait..." | reboot
+		dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Restarting... Please wait..." 
+		reboot
 	else
 		dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Abort!"
 fi
